@@ -1,6 +1,8 @@
 from .anonymizer import (
     SupervisedLearningAnonymizer,
+    TFKerasWrapper,
     WrappedAnonymizer,
+    batch_views,
     pickle_anonymizer,
     unpickle_anonymizer,
 )
@@ -11,11 +13,13 @@ from .anonymizer_server import (
 )
 
 __all__ = [
+    "batch_views",
     "InferenceResource",
     "pickle_anonymizer",
     "supervised_learning_anonymizer_server_factory",
     "SupervisedLearningAnonymizer",
     "unpickle_anonymizer",
+    "TFKerasWrapper",
     "validate_anonymizer_input_or_raise",
     "WrappedAnonymizer",
 ]
