@@ -15,8 +15,9 @@ logger = logging.getLogger(__name__)
 
 
 class InferenceResource:
-    """This resource is intended for fitting estimator following the supervised
-    learning paradigm.
+    """This resource is intended for providing inference access to a fitted
+    anonymizer (that follows the supervised learning paradigm) and to invoke its
+    evaluation.
     """
 
     def __init__(
@@ -29,6 +30,35 @@ class InferenceResource:
         validation_data_url: str,
         utility_evaluation_url: str,
     ) -> None:
+        """
+        Parameters
+        ----------
+        anonymizer_identifier : str
+            The identifier of the anonymizer which will be loaded for inference
+            or evaluation. This is required by the corresponding challenge's
+            evaluation API.
+        model_filepath : str | Path
+            Where to load a fitted model from for inference (argument to
+            `model_loader`).
+        model_loader : Callable[[str  |  Path], anonymizer.SupervisedLearningAnonymizer]
+            A function that is able to recover an instance of
+            `anonymizer.SupervisedLearningAnonymizer` from `model_filepath`. In
+            case `anonymizer_obj` is a wrapped object, keep in mind that this
+            loader has to recover the outer object too, not just the inner
+            object.
+        default_batch_size : int
+            A default batch size to use, if none is specified in the requests.
+        tuning_data_url : str
+            Where to obtain tuning data from (usually, this points to an API of
+            the challenge you are submitting your anonymizer to).
+        validation_data_url : str
+            Where to obtain validation data from (usually, this points to an API
+            of the challenge you are submitting your anonymizer to).
+        utility_evaluation_url : str
+            Where to submit the target values this anonymizer inferred from the
+            validation data features (usually, this points to an API of the
+            challenge you are submitting your anonymizer to).
+        """
         self._anon_id = anonymizer_identifier
         self._model_filepath = Path(model_filepath)
         self._load_model = model_loader
@@ -177,8 +207,26 @@ def supervised_learning_anonymizer_server_factory(
 
     Parameters
     ----------
+    anonymizer_identifier : str
+        Passed to `InferenceResource`.
     anonymizer_obj : anonymizer.SupervisedLearningAnonymizer
-        An anonymizer that is based on the supervised learning paradigm
+        An anonymizer that is based on the supervised learning paradigm.
+    model_filepath : str | Path
+        Where to save the fitted model after training / where to load it back
+        from for inference.
+    default_batch_size : int
+        Passed to `InferenceResource`.
+    training_data_url : str
+        Where to obtain training data from (usually, this points to an API of
+        the challenge you are submitting your anonymizer to).
+    tuning_data_url : str
+        Passed to `InferenceResource`.
+    validation_data_url : str
+        Passed to `InferenceResource`.
+    utility_evaluation_url : str
+        Passed to `InferenceResource`.
+    model_loader : Callable[[str  |  Path], anonymizer.SupervisedLearningAnonymizer]
+        Passed to `InferenceResource`.
 
     Returns
     -------
